<?php

// Prevent direct access to this file
if (!defined('ABSPATH')) {
    exit;
}

class SMAFFDKN_Admin {
    public function __construct() {
        add_action('admin_menu', array($this, 'add_admin_menu'));
        add_action('admin_init', array($this, 'register_settings'));
    }

    public function add_admin_menu() {
        add_menu_page(
            'Smart Affiliate Dokan',
            'Smart Affiliate',
            'manage_options',
            'smart-affiliate-for-dokan',
            array($this, 'admin_page_content'),
            'dashicons-groups',
            55
        );
    }

    public function register_settings() {
        register_setting('smaffdkn_options_group', 'smaffdkn_commission_rate', array(
            'type' => 'integer',
            'sanitize_callback' => 'absint',
            'default' => 10,
        ));
        register_setting('smaffdkn_options_group', 'smaffdkn_discount_rate', array(
            'type' => 'integer',
            'sanitize_callback' => 'absint',
            'default' => 10,
        ));
        add_settings_section(
            'smaffdkn_general_section',
            __('General Settings', 'smart-affiliate-for-dokan'),
            null,
            'smart-affiliate-for-dokan'
        );
        add_settings_field(
            'smaffdkn_commission_rate',
            __('Default Commission Rate (%)', 'smart-affiliate-for-dokan'),
            array($this, 'commission_rate_field_callback'),
            'smart-affiliate-for-dokan',
            'smaffdkn_general_section'
        );
        add_settings_field(
            'smaffdkn_discount_rate',
            __('Referral Discount Rate (%)', 'smart-affiliate-for-dokan'),
            array($this, 'discount_rate_field_callback'),
            'smart-affiliate-for-dokan',
            'smaffdkn_general_section'
        );
    }

    public function commission_rate_field_callback() {
        ?>
        <input type="number" name="smaffdkn_commission_rate" value="<?php echo esc_attr(get_option('smaffdkn_commission_rate', 10)); ?>" class="small-text" min="0" max="100" />%
        <?php
    }

    public function discount_rate_field_callback() {
        ?>
        <input type="number" name="smaffdkn_discount_rate" value="<?php echo esc_attr(get_option('smaffdkn_discount_rate', 10)); ?>" class="small-text" min="0" max="100" />%
        <?php
    }

    public function admin_page_content() {
        ?>
        <div class="wrap">
            <h1><?php esc_html_e('Smart Affiliate Dokan Settings', 'smart-affiliate-for-dokan'); ?></h1>
            <?php settings_errors(); ?>
            <form method="post" action="options.php">
                <?php
                settings_fields('smaffdkn_options_group');
                do_settings_sections('smart-affiliate-for-dokan');
                submit_button(esc_html__('Save Settings', 'smart-affiliate-for-dokan'));
                ?>
            </form>
        </div>
        <?php
    }
}

new SMAFFDKN_Admin();